<h1 align="center">
  <br>
  <a href="https://github.com/crinny/b0mb3r"><img src="https://emojipedia-us.s3.dualstack.us-west-1.amazonaws.com/thumbs/120/apple/237/bomb_1f4a3.png" alt="b0mb3r"></a>
  <br>
  boomber
  <br>
</h1>

<h4 align="center">Открытый и бесплатный СМС бомбер</h4>

<p align="center">
  <a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg">
  </a>
  <a href="https://pepy.tech/project/b0mb3r">
    <img src="https://pepy.tech/badge/b0mb3r">
  </a>
  <a href="https://github.com/crinny/b0mb3r/blob/master/LICENSE">
    <img src="https://img.shields.io/badge/License-MPL%202.0-yellow.svg">
  </a>
</p>

<p align="center">
  <a href="https://github.com/crinny/b0mb3r/wiki/%D0%A3%D1%81%D1%82%D0%B0%D0%BD%D0%BE%D0%B2%D0%BA%D0%B0">Установка</a> •
  <a href="https://github.com/crinny/b0mb3r/wiki">Расширенное использование</a>
</p>

## Документация
- [Установка](https://github.com/crinny/b0mb3r/wiki/%D0%A3%D1%81%D1%82%D0%B0%D0%BD%D0%BE%D0%B2%D0%BA%D0%B0)
- [API](https://github.com/crinny/b0mb3r/wiki/API)
- [Аргументы командной строки](https://github.com/crinny/b0mb3r/wiki/Аргументы-командной-строки)
- [Проекты, использующие b0mb3r](https://github.com/crinny/b0mb3r/wiki/Проекты,-использующие-b0mb3r)
- [Когда что то идёт не так](https://github.com/crinny/b0mb3r/wiki/Когда-что-то-идёт-не-так)

Канал с новостями о разработке в Telegram: [@b0mb3rch](https://t.me/b0mb3rch).

## Лицензия
<!--- Не надо это удалять, пожалуйста 😐  -->
Проект распространяется под лицензией [Mozilla Public License 2.0](https://github.com/crinny/b0mb3r/blob/master/LICENSE). Скачивая программное обеспечение из [этого](https://github.com/crinny/b0mb3r) репозитория, вы соглашаетесь с ней. По условиям лицензии вы обязаны выкладывать исходный код ваших модификаций под той же лицензией.


## Contributors ✨

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-12-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://t.me/crinny"><img src="https://avatars1.githubusercontent.com/u/42045258?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Nikita</b></sub></a><br /><a href="#question-crinny" title="Answering Questions">💬</a> <a href="https://github.com/crinny/b0mb3r/issues?q=author%3Acrinny" title="Bug reports">🐛</a> <a href="https://github.com/crinny/b0mb3r/commits?author=crinny" title="Code">💻</a> <a href="#design-crinny" title="Design">🎨</a> <a href="https://github.com/crinny/b0mb3r/commits?author=crinny" title="Documentation">📖</a> <a href="#fundingFinding-crinny" title="Funding Finding">🔍</a> <a href="#ideas-crinny" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-crinny" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a> <a href="#maintenance-crinny" title="Maintenance">🚧</a> <a href="#platform-crinny" title="Packaging/porting to new platform">📦</a> <a href="#projectManagement-crinny" title="Project Management">📆</a> <a href="https://github.com/crinny/b0mb3r/pulls?q=is%3Apr+reviewed-by%3Acrinny" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/ifamed"><img src="https://avatars1.githubusercontent.com/u/9146326?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Dmitry</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=ifamed" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/its5Q"><img src="https://avatars1.githubusercontent.com/u/12975646?v=4?s=100" width="100px;" alt=""/><br /><sub><b>its5Q</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=its5Q" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/nm17"><img src="https://avatars2.githubusercontent.com/u/23419131?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Даниил Николаев</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=nm17" title="Code">💻</a> <a href="https://github.com/crinny/b0mb3r/commits?author=nm17" title="Documentation">📖</a> <a href="#financial-nm17" title="Financial">💵</a> <a href="#ideas-nm17" title="Ideas, Planning, & Feedback">🤔</a> <a href="#tool-nm17" title="Tools">🔧</a> <a href="https://github.com/crinny/b0mb3r/pulls?q=is%3Apr+reviewed-by%3Anm17" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="https://github.com/catofsof"><img src="https://avatars0.githubusercontent.com/u/58178903?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Kirill Link</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=catofsof" title="Code">💻</a> <a href="#design-catofsof" title="Design">🎨</a></td>
    <td align="center"><a href="https://github.com/cxiodev"><img src="https://avatars2.githubusercontent.com/u/39461931?v=4?s=100" width="100px;" alt=""/><br /><sub><b>cxiodev</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=cxiodev" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/mishailovic"><img src="https://avatars2.githubusercontent.com/u/41520056?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Mikhail Kuznetsov</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=mishailovic" title="Documentation">📖</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/asinedd"><img src="https://avatars1.githubusercontent.com/u/67601784?v=4?s=100" width="100px;" alt=""/><br /><sub><b>asinedd</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=asinedd" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/aiexz"><img src="https://avatars3.githubusercontent.com/u/42418433?v=4?s=100" width="100px;" alt=""/><br /><sub><b>aiexz</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=aiexz" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/GameTrue"><img src="https://avatars3.githubusercontent.com/u/45202887?v=4?s=100" width="100px;" alt=""/><br /><sub><b>GameTrue</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/issues?q=author%3AGameTrue" title="Bug reports">🐛</a> <a href="https://github.com/crinny/b0mb3r/commits?author=GameTrue" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/AntsiferovBogdan"><img src="https://avatars1.githubusercontent.com/u/58101453?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Antsiferov Bogdan</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=AntsiferovBogdan" title="Code">💻</a> <a href="#design-AntsiferovBogdan" title="Design">🎨</a></td>
    <td align="center"><a href="https://vipapp.site/"><img src="https://avatars2.githubusercontent.com/u/46930374?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Alex Sokol</b></sub></a><br /><a href="https://github.com/crinny/b0mb3r/commits?author=y9san9" title="Documentation">📖</a></td>
  </tr>
</table>

<!-- markdownlint-enable -->
<!-- prettier-ignore-end -->
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
